@@ -6,6 +6,7 @@ datazen - Top-level APIs for loading and interacting with configuration data.
 from typing import List
 
 # internal
+from datazen.code.types import LoadResult
 from datazen.load import DEFAULT_LOADS, LoadedFiles, load_dir
 
 
@@ -13,10 +14,11 @@ def load(
     directories: List[str],
     variable_data: dict = None,
     loads: LoadedFiles = DEFAULT_LOADS,
-) -> dict:
+) -> LoadResult:
     """Load configuration data from a list of directories."""
 
     result: dict = {}
+    errors = 0
     for directory in directories:
-        load_dir(directory, result, variable_data, loads)
-    return result
+        errors += int(not load_dir(directory, result, variable_data, loads)[1])
+    return LoadResult(result, errors == 0)
