@@ -8,6 +8,9 @@ import logging
 import os
 from typing import List
 
+# third-party
+from vcorelib.logging import log_time
+
 # internal
 from datazen import CACHE_SUFFIX
 from datazen.environment.base import TaskResult, dep_slug_unwrap
@@ -58,12 +61,13 @@ class Environment(
             targets.append(self.default_target())
 
         for target in targets:
-            task_result = self.execute(target, False)
-            if not task_result[0]:
-                self.logger.error("target '%s' failed", target)
-                return False
-            if not task_result[1]:
-                self.logger.info("'%s' already satisfied", target)
+            with log_time(self.logger, "Target '%s'", target):
+                task_result = self.execute(target, False)
+                if not task_result[0]:
+                    self.logger.error("target '%s' failed", target)
+                    return False
+                if not task_result[1]:
+                    self.logger.info("'%s' already satisfied", target)
 
         # write the cache at the end, if we were totally successful
         self.write_cache()
