@@ -8,10 +8,11 @@ from io import StringIO
 import logging
 from pathlib import Path
 import time
-from typing import List, Union
+from typing import Union
 
 # third-party
 import jinja2
+from vcorelib.dict import merge
 
 # internal
 from datazen.code import ARBITER
@@ -25,16 +26,22 @@ def load_stream(
     data_stream: DataStream,
     path: Union[Path, str],
     logger: logging.Logger = LOG,
+    require_success: bool = False,
     **kwargs,
 ) -> LoadResult:
     """
     Load arbitrary data from a text stream, update an existing dictionary.
     """
 
-    return ARBITER.decode_stream(
+    result = ARBITER.decode_stream(
         get_file_ext(path), data_stream, logger, **kwargs
     )
 
+    if require_success:
+        result.require_success(path)
+
+    return result
+
 
 def dedup_dict_lists(data: dict) -> dict:
     """
@@ -55,87 +62,6 @@ def dedup_dict_lists(data: dict) -> dict:
     return data
 
 
-def merge_dicts(
-    dicts: List[dict],
-    expect_overwrite: bool = False,
-    logger: logging.Logger = LOG,
-) -> dict:
-    """
-    Merge a list of dictionary data into a single set (mutates the first
-    element).
-    """
-
-    result = dicts[0]
-    for right_dict in dicts[1:]:
-        result = merge(
-            result,
-            right_dict,
-            expect_overwrite=expect_overwrite,
-            logger=logger,
-        )
-    return result
-
-
-def merge(
-    dict_a: dict,
-    dict_b: dict,
-    path: List[str] = None,
-    expect_overwrite: bool = False,
-    logger: logging.Logger = LOG,
-) -> dict:
-    """
-    Combine two dictionaries recursively, prefers dict_a in a conflict. For
-    values of the same key that are lists, the lists are combined. Otherwise
-    the resulting dictionary is cleanly merged.
-    """
-
-    if path is None:
-        path = []
-
-    for key in dict_b:
-        if key in dict_a:
-            # first try to coerce b's type into a's
-            if not isinstance(dict_b[key], type(dict_a[key])):
-                try:
-                    dict_b[key] = type(dict_a[key])(dict_b[key])
-                except ValueError:
-                    pass
-
-            # same leaf value
-            if dict_a[key] == dict_b[key]:
-                pass
-            elif isinstance(dict_a[key], dict) and isinstance(
-                dict_b[key], dict
-            ):
-                merge(
-                    dict_a[key],
-                    dict_b[key],
-                    path + [str(key)],
-                    expect_overwrite,
-                    logger,
-                )
-            elif isinstance(dict_a[key], list) and isinstance(
-                dict_b[key], list
-            ):
-                dict_a[key].extend(dict_b[key])
-            elif not isinstance(dict_b[key], type(dict_a[key])):
-                logger.error(
-                    "Type mismatch at '%s'", ".".join(path + [str(key)])
-                )
-                logger.error("left:  %s (%s)", type(dict_a[key]), dict_a[key])
-                logger.error("right: %s (%s)", type(dict_b[key]), dict_b[key])
-            elif not expect_overwrite:
-                logger.error("Conflict at '%s'", ".".join(path + [str(key)]))
-                logger.error("left:  %s", dict_a[key])
-                logger.error("right: %s", dict_b[key])
-            else:
-                dict_a[key] = dict_b[key]
-        else:
-            dict_a[key] = dict_b[key]
-
-    return dict_a
-
-
 def load(
     path: Union[Path, str],
     variables: dict,
@@ -143,6 +69,7 @@ def load(
     expect_overwrite: bool = False,
     is_template: bool = True,
     logger: logging.Logger = LOG,
+    **kwargs,
 ) -> LoadResult:
     """
     Load raw file data and meld it into an existing dictionary. Update
@@ -178,7 +105,7 @@ def load(
         )
         return result
 
-    load_result = load_stream(StringIO(str_output), path, logger)
+    load_result = load_stream(StringIO(str_output), path, logger, **kwargs)
     return LoadResult(
         merge(
             dict_to_update, load_result.data, expect_overwrite=expect_overwrite
